@@ -77,6 +77,7 @@ class Runner:
 
         self.hooks[ hook ] = method
 
+
     @property
     def semaphore( self ):
         """
@@ -84,6 +85,7 @@ class Runner:
         """
         return self._semaphore
 
+
     def set_semaphore( self, value ):
         """
         Sets the semaphore to use.
@@ -92,7 +94,6 @@ class Runner:
         :raises RuntimeError: If semaphore is already set.
         :raises TypeError: If semaphore is invalid.
         """
-
         if self._semaphore is not None:
             raise RuntimeError( 'Semaphore already set.' )
 
@@ -185,6 +186,7 @@ class Runner:
         if verbose:
             logger.info( f'[Container { root._id }] { perf_counter() - subtree_start } s' )
 
+
     def eval_tree_sync(
         self,
         root,
@@ -200,6 +202,7 @@ class Runner:
         """
         asyncio.run( self.eval_tree( root, tasks = tasks, **eval_args ) )
 
+
     async def eval_container(
         self,
         container,
@@ -242,6 +245,7 @@ class Runner:
             except asyncio.CancelledError as err:
                 break
 
+
     async def run_scripts(
         self,
         container,
@@ -266,6 +270,11 @@ class Runner:
             :param association: ScriptAssociation to run.
             """
             async def _execute_script( script_id, script_path ):
+                """
+                :param script_id:
+                :param script_path:
+                :returns:
+                """
                 if verbose:
                     logger.info( f'Running script {script_id} on container {container._id}' )
                     eval_start = perf_counter()
@@ -286,6 +295,13 @@ class Runner:
                     # other error
                     self.hooks[ 'script_error' ]( err, script_id, container, ignore_errors )
 
+                    # TODO [1]: Asset creation not tracked
+                    #           if error occurs after an asset is created.
+                    #           For now if an error occurs, do not track Asset
+                    #           creation.
+                    script_assets = ''
+
+
                 except asyncio.CancelledError as err:
                     raise err
 
@@ -296,6 +312,7 @@ class Runner:
 
                 return script_assets
 
+
             ( script_id, script_path ) = self.hooks[ 'get_script_info' ]( association.script )
 
             # execute script
@@ -315,6 +332,7 @@ class Runner:
 
                 self.hooks[ 'assets_added' ]( script_assets )
 
+
         # eval container
         tasks = []
         for association in associations:
@@ -330,6 +348,7 @@ class Runner:
         except asyncio.CancelledError as err:
             raise err
 
+
     async def run_script( self, script_id, script_path, container_id ):
         """
         Runs the given program on the given Container asynchronously.
@@ -371,6 +390,7 @@ class Runner:
 
         return stdout
 
+
     # --- helpers ---
 
     def _check_hooks( self ):
@@ -388,6 +408,7 @@ class Runner:
 
         return True
 
+
     def filter_scripts( self, associations, scripts ):
         """
         Filters scripts.
@@ -405,6 +426,7 @@ class Runner:
             ( script_id, _) = self.hooks[ 'get_script_info' ]( association.script )
             return ( script_id in scripts )
 
+
         filtered = filter(
             lambda assoc: _filter_script( assoc, scripts ),
             associations
@@ -412,6 +434,7 @@ class Runner:
 
         return filtered
 
+
     async def _terminate_procs( self, sig = signal.SIGINT ):
         procs = []
         for _, proc in self._procs.items():
@@ -427,6 +450,7 @@ class Runner:
 
         await asyncio.gather( *procs )
 
+
     async def _exit_tasks( self, sig ):
         """
         End all tasks.
@@ -445,6 +469,7 @@ class Runner:
 
         await self._exit_task
 
+
     def _register_signal_handlers( self ):
         """
         """
@@ -456,9 +481,9 @@ class Runner:
             self._exit_task = loop.create_task( self._exit_tasks( sig ) )
 
         if platform.system() == 'Windows':
-        	# signal handlers do not exist on windows
-        	# TODO [1]: Add signal handling for Windows.
-        	return
+            # signal handlers do not exist on windows
+            # TODO [1]: Add signal handling for Windows.
+            return
 
         loop = asyncio.get_running_loop()
         for signame in { 'SIGINT', 'SIGTERM' }:
@@ -469,6 +494,7 @@ class Runner:
                 partial( _exit, sig, loop )
             )
 
+
     @staticmethod
     def group_scripts( associations ):
         """
@@ -488,6 +514,7 @@ class Runner:
 
         return groups
 
+
     @staticmethod
     def _default_script_error_handler(
         err,
@@ -513,6 +540,7 @@ class Runner:
             err.cmd = msg
             raise err
 
+
     @staticmethod
     def create_thot_env( container_id, script_id ):
         """
@@ -528,6 +556,7 @@ class Runner:
 
         return env
 
+        
     @staticmethod
     def get_kwarg( key, kwargs, default = None):
         """
